# Mozilla User Preferences
// This is a generated file!

user_pref("browser.startup.homepage", "http://plamo-linux.jp/");
user_pref("startup.homepage_override_url", "http://plamo-linux.jp/plamo-4.6.html");
user_pref("font.default", "sans-serif");
user_pref("font.name.cursive.ja", "alias-serif-jisx0208.1983-0");
user_pref("font.name.fantasy.ja", "alias-serif-jisx0208.1983-0");
user_pref("font.name.monospace.ja", "alias-monospace-jisx0208.1983-0");
user_pref("font.name.sans-serif.ja", "alias-sans-jisx0208.1983-0");
user_pref("font.name.serif.ja", "alias-serif-jisx0208.1983-0");
user_pref("xim.input_style", "over-the-spot");
